@@ -1,25 +1,25 @@
 package cautils
 
 import (
-	"github.com/armosec/kubescape/cautils/armotypes"
-	"github.com/armosec/kubescape/cautils/opapolicy"
+	"github.com/armosec/armoapi-go/armotypes"
+	"github.com/armosec/opa-utils/reporthandling"
 )
 
 // K8SResources map[<api group>/<api version>/<resource>]<resource object>
 type K8SResources map[string]interface{}
 
 type OPASessionObj struct {
-	Frameworks    []opapolicy.Framework
+	Frameworks    []reporthandling.Framework
 	K8SResources  *K8SResources
 	Exceptions    []armotypes.PostureExceptionPolicy
-	PostureReport *opapolicy.PostureReport
+	PostureReport *reporthandling.PostureReport
 }
 
-func NewOPASessionObj(frameworks []opapolicy.Framework, k8sResources *K8SResources) *OPASessionObj {
+func NewOPASessionObj(frameworks []reporthandling.Framework, k8sResources *K8SResources) *OPASessionObj {
 	return &OPASessionObj{
 		Frameworks:   frameworks,
 		K8SResources: k8sResources,
-		PostureReport: &opapolicy.PostureReport{
+		PostureReport: &reporthandling.PostureReport{
 			ClusterName:  ClusterName,
 			CustomerGUID: CustomerGUID,
 		},
@@ -30,7 +30,7 @@ func NewOPASessionObjMock() *OPASessionObj {
 	return &OPASessionObj{
 		Frameworks:   nil,
 		K8SResources: nil,
-		PostureReport: &opapolicy.PostureReport{
+		PostureReport: &reporthandling.PostureReport{
 			ClusterName:  "",
 			CustomerGUID: "",
 			ReportID:     "",
@@ -44,8 +44,8 @@ type ComponentConfig struct {
 }
 
 type Exception struct {
-	Ignore        *bool                 `json:"ignore"`        // ignore test results
-	MultipleScore *opapolicy.AlertScore `json:"multipleScore"` // MultipleScore number - float32
-	Namespaces    []string              `json:"namespaces"`
-	Regex         string                `json:"regex"` // not supported
+	Ignore        *bool                      `json:"ignore"`        // ignore test results
+	MultipleScore *reporthandling.AlertScore `json:"multipleScore"` // MultipleScore number - float32
+	Namespaces    []string                   `json:"namespaces"`
+	Regex         string                     `json:"regex"` // not supported
 }
