@@ -31,7 +31,7 @@ var controlCmd = &cobra.Command{
 		scanInfo.PolicyIdentifier.Kind = reporthandling.KindControl
 		scanInfo.Init()
 		cautils.SetSilentMode(scanInfo.Silent)
-		err := clihandler.CliSetup(scanInfo)
+		err := clihandler.CliSetup(&scanInfo)
 		if err != nil {
 			fmt.Fprintf(os.Stderr, "error: %v\n", err)
 			os.Exit(1)
